==> haskell-storable-tuple-0.0.3.3-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.0.3.3
visibility:           public
id:                   storable-tuple-0.0.3.3-9SZEKphVeh6IheUmHofIg
key:                  storable-tuple-0.0.3.3-9SZEKphVeh6IheUmHofIg
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.

category:             Data, Foreign
abi:                  977698c93209f895b404b33bf0b2dd91
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-8.10.4/site-local/storable-tuple-0.0.3.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/storable-tuple-0.0.3.3
hs-libraries:         HSstorable-tuple-0.0.3.3-9SZEKphVeh6IheUmHofIg
depends:
    base-4.14.1.0 base-orphans-0.8.4-BhJbjtQB8nyLOtIFKX6qPB
    storable-record-0.0.5-2iZDju5z5vyJhahRhtqAu4
    utility-ht-0.0.16-7TgTpbTPgsFF0gG3RN7zIH

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.0.3.3
visibility:           public
id:                   storable-tuple-0.0.3.3-G2c6y4Ou4dn8HJaUfaetQT
key:                  storable-tuple-0.0.3.3-G2c6y4Ou4dn8HJaUfaetQT
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.

category:             Data, Foreign
abi:                  e9281b65ea1e8c17f4fd50b0889a06c1
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-8.10.4/site-local/storable-tuple-0.0.3.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/storable-tuple-0.0.3.3
hs-libraries:         HSstorable-tuple-0.0.3.3-G2c6y4Ou4dn8HJaUfaetQT
depends:
    base-4.14.1.0 base-orphans-0.8.4-3MSGonGBqpO2VX3HqLdhO3
    storable-record-0.0.5-5s2JaDaSaasDbe3cuvCUIi
    utility-ht-0.0.16-2WDsPDWsimqHa7f4bSgNbg

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
